@@ -485,7 +485,7 @@ class BaseDatabaseOperations(object):
             raise ValueError("Django does not support timezone-aware times.")
         return six.text_type(value)
 
-    def adapt_decimalfield_value(self, value, max_digits, decimal_places):
+    def adapt_decimalfield_value(self, value, max_digits=None, decimal_places=None):
         """
         Transforms a decimal.Decimal value to an object compatible with what is
         expected by the backend driver for decimal (numeric) columns.
@@ -497,7 +497,7 @@ class BaseDatabaseOperations(object):
         Transforms a string representation of an IP address into the expected
         type for the backend driver.
         """
-        return value
+        return value or None
 
     def year_lookup_bounds_for_date_field(self, value):
         """
